==> react-native-hotqa-sdk-0.1.1.tgz: package/src/components/reorder/index2.js <==
import React, {useRef} from 'react';
import {StyleSheet, View, Text} from 'react-native';
import {onConfigurations} from '../../common/helper';
import Tags from '../tag/Tags';
import SharePreference from '../../common/SharePreference';

export default (props) => {
  const {item, dispatch, isFinish} = props;
  let _tagsComponent0 = useRef(null);
  let _tagsComponent1 = useRef(null);
  let {configurations} = item;
  configurations = JSON.parse(configurations);
  const correctAnswer = configurations.correct_answer;

  const arrData = [];
  const arrAnswerNew = [];
  const dataSelected = [];
  correctAnswer.forEach((i) => {
    arrData.push(i);
    arrAnswerNew.push(i + ' ');
    dataSelected.push('');
  });
  arrData.sort();

  // arrData.forEach((i) => {
  //   dataSelected.push('');
  // });

  const onDragEnd = (data) => {
    if (!isFinish) {
      let convertData = [];
      data.forEach((item) => {
        convertData.push(item.title);
      });
      onConfigurations(item, convertData, dispatch);
    }
  };

  const onSubmitNewTag = (tag, type, refTag) => {
    if (!isFinish) {
      refTag && refTag.onSubmitNewTag(tag, type);
    }
  };

  return (
    <View style={styles.configView}>
      <Tags
        ref={(component) => (_tagsComponent0 = component)}
        tags={arrData}
        type={0}
        tagSelected={false}
        onDragRelease={(data) => onDragEnd(data)}
        onPress={(tag) => onSubmitNewTag(tag, 0, _tagsComponent1)}
      />
      <View style={{marginTop: 100}}>
        <Tags
          ref={(component) => (_tagsComponent1 = component)}
          tags={dataSelected}
          type={1}
          tagSelected={true}
          onDragRelease={(data) => onDragEnd(data)}
          onPress={(tag) => onSubmitNewTag(tag, 1, _tagsComponent0)}
        />
      </View>
      {isFinish && (
        <Text style={styles.textAnswer}>
          Đáp án:{'   '} {arrAnswerNew}
        </Text>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  configView: {
    flex: 1,
    alignItems: 'center',
  },
  text: {
    color: 'black',
    fontSize: 14,
  },
  item: {
    paddingVertical: 8,
    paddingHorizontal: 20,
    alignItems: 'center',
    justifyContent: 'center',
    borderColor: '#FDA429',
    borderWidth: 2,
    borderRadius: 20,
    marginHorizontal: 5,
  },
  textAnswer: {
    color: 'red',
    fontSize: 18,
    marginTop: 100,
  },
});

==> react-native-hotqa-sdk-0.1.9.tgz: package/src/components/reorder/index2.js <==
import React, {useRef} from 'react';
import {StyleSheet, View, Text} from 'react-native';
import {onConfigurations} from '../../common/helper';
import Tags from '../tag/Tags';

export default (props) => {
  const {item, dispatch, isFinish, user_answer} = props;
  let _tagsComponent0 = useRef(null);
  let _tagsComponent1 = useRef(null);
  let {configurations} = item;
  configurations = JSON.parse(configurations);
  const correctAnswer = configurations.correct_answer;

  const arrData = [];
  const arrAnswerNew = [];
  let dataSelected = [];
  correctAnswer.forEach((i) => {
    arrData.push(i);
    arrAnswerNew.push(i + ' ');
    dataSelected.push('');
  });
  arrData.sort();

  user_answer.forEach((answer) => {
    if (item.id === answer.question_id && answer.user_answer.value !== '') {
      dataSelected = answer.user_answer.value;
    }
  });

  const onDragEnd = (data) => {
    if (!isFinish) {
      let convertData = [];
      data.forEach((item) => {
        convertData.push(item.title);
      });
      onConfigurations(item, convertData, dispatch);
    }
  };

  const onSubmitNewTag = (tag, type, refTag) => {
    if (!isFinish) {
      refTag && refTag.onSubmitNewTag(tag, type);
    }
  };

  return (
    <View style={styles.configView}>
      <Tags
        ref={(component) => (_tagsComponent0 = component)}
        tags={arrData}
        type={0}
        tagSelected={false}
        isFinish={isFinish}
        onDragRelease={(data) => onDragEnd(data)}
        onPress={(tag) => onSubmitNewTag(tag, 0, _tagsComponent1)}
      />
      <View style={{marginTop: 100}}>
        <Tags
          ref={(component) => (_tagsComponent1 = component)}
          tags={dataSelected}
          type={1}
          tagSelected={true}
          isFinish={isFinish}
          onDragRelease={(data) => onDragEnd(data)}
          onPress={(tag) => onSubmitNewTag(tag, 1, _tagsComponent0)}
        />
      </View>
      {isFinish && (
        <Text style={styles.textAnswer}>
          Đáp án:{'   '} {arrAnswerNew}
        </Text>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  configView: {
    flex: 1,
    alignItems: 'center',
  },
  text: {
    color: 'black',
    fontSize: 14,
  },
  item: {
    paddingVertical: 8,
    paddingHorizontal: 20,
    alignItems: 'center',
    justifyContent: 'center',
    borderColor: '#FDA429',
    borderWidth: 2,
    borderRadius: 20,
    marginHorizontal: 5,
  },
  textAnswer: {
    color: 'red',
    fontSize: 18,
    marginTop: 100,
  },
});
